%   myletter.cls
%   Modified version of mpletter.cls
%   from Kopka and Daly's book
%   L. Peliti 2017/07/12
%   (C) 2017 Luca Peliti

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{myletter}[2017/07/12 v1.1 (L. Peliti)]

\RequirePackage{ifthen,graphicx,eurosym}
\RequirePackage[utf8x]{inputenc}
\newcommand{\langu@ge}{english}

\newcommand{\noheadton@me}{}

\DeclareOption{italian}{\renewcommand{\langu@ge}{italian}}
\DeclareOption{italiano}{\renewcommand{\langu@ge}{italian}}
\DeclareOption{francais}{\renewcommand{\langu@ge}{francais}}
\DeclareOption{french}{\renewcommand{\langu@ge}{francais}}
\DeclareOption{nohead}{\renewcommand{\noheadton@me}{yes}}
\DeclareOption{english}{}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{letter}}
\ProcessOptions
\LoadClass{letter}

\newcommand{\englishnames}{%
    \newcommand{\subjectname}{\textsl{Subject}}
    \newcommand{\telephonename}{Tel}
    \newcommand{\sendname}{\textsl{From}}
    \renewcommand{\enclname}{\textsl{Enclosed}}
    \renewcommand{\ccname}{\textsl{cc}}
}

\newcommand{\italiannames}{%
    \newcommand{\subjectname}{\textsl{Oggetto}}
    \newcommand{\telephonename}{Tel}
    \newcommand{\sendname}{\textsl{Da}}
    \renewcommand{\enclname}{\textsl{Allegati}}
    \renewcommand{\ccname}{\textsl{e p.c.}}
}

\newcommand{\frenchnames}{%
    \newcommand{\subjectname}{\textsl{Sujet}}
    \newcommand{\telephonename}{T\'el}
    \newcommand{\sendname}{\textsl{De}}
    \renewcommand{\enclname}{\textsl{Encl.}}
    \renewcommand{\ccname}{\textsl{cc}}
    \renewcommand{\headtoname}{\textsl{\`A}}
}

\ifthenelse{\equal{\langu@ge}{italian}}
    {\RequirePackage[italian]{babel}\italiannames}{%
    \ifthenelse{\equal{\langu@ge}{francais}}
        {\RequirePackage[frenchb]{babel}\frenchnames}{\englishnames}}

\newcommand{\@subject}{}
\newcommand{\@internet}{}   \newcommand{\@faxnum}{}
\newcommand{\subject}[1]{\renewcommand{\@subject}{#1}}
\newcommand{\internet}[1]{\renewcommand{\@internet}{#1}}
\newcommand{\INTERNET}{}
\newcommand{\telefax}[1]{\renewcommand{\@faxnum}{#1}}
\newcommand{\@cedex}{}
\newcommand{\cedex}[1]{\renewcommand{\@cedex}{#1}}

\newcommand{\countryname}{}
\newcommand{\fromtelcode}{}
\newcommand{\webp@ge}{}
\newcommand{\fromcode}{}
\newcommand{\cityname}{}
\newcommand{\instname}{}
\newcommand{\dept}{}
\newcommand{\specname}{}
\newcommand{\fromlogo}{}
\newcommand{\street}[1]{\renewcommand{\fromaddress}{#1}}
\newcommand{\city}[1]{\renewcommand{\cityname}{#1}}
\newcommand{\postcode}[1]{\renewcommand{\fromcode}{#1}}
\newcommand{\country}[1]{\renewcommand{\countryname}{#1}}
\newcommand{\telcode}[1]{\renewcommand{\fromtelcode}{#1}}
\newcommand{\logo}[1]{\renewcommand{\fromlogo}{#1}}
\newcommand{\institute}[1]{\renewcommand{\instname}{#1}}
\newcommand{\department}[1]{\renewcommand{\dept}{#1}}
\newcommand{\spec}[1]{\renewcommand{\specname}{#1}}
\newcommand{\web}[1]{\renewcommand{\webp@ge}{#1}}


%   Basic lengths defined for A4 paper
\setlength{\textheight}{215mm}  \setlength{\textwidth}{160mm}
\setlength{\oddsidemargin}{0pt} \setlength{\evensidemargin}{0pt}
\setlength{\topmargin}{-20pt}   \setlength{\headheight}{12pt}
\setlength{\headsep}{35pt}

\DeclareFixedFont{\xviisf}{OT1}{cmss}{m}{n}{17}
\DeclareFixedFont{\xvsf}{OT1}{cmss}{m}{n}{14.4}
\DeclareFixedFont{\xvsfbx}{OT1}{cmss}{bx}{n}{14.4}
\DeclareFixedFont{\xiisf}{OT1}{cmss}{m}{n}{12}
\DeclareFixedFont{\xivsf}{OT1}{cmss}{m}{n}{14}
\DeclareFixedFont{\xivsfbx}{OT1}{cmss}{bx}{n}{14}
\DeclareFixedFont{\xsf}{OT1}{cmss}{m}{n}{10}
\DeclareFixedFont{\xsfbx}{OT1}{cmss}{bx}{n}{10}
\DeclareFixedFont{\viiisf}{OT1}{cmss}{m}{n}{8}

\newlength{\leftfield}  \setlength{\leftfield}{110mm}
\newlength{\rightfield} \setlength{\rightfield}{50mm}
\newlength{\headfield}  \setlength{\headfield}{75mm}

\newsavebox{\FIRM}  \newsavebox{\citydate}
\newsavebox{\firm}

\AtBeginDocument{%

\ifthenelse{\equal{\noheadton@me}{yes}}{\renewcommand{\headtoname}{}}{}

\newsavebox{\fromaddressbox}
\sbox{\fromaddressbox}
   {\parbox[b]{\headfield}{\center\xiisf 
   \fromaddress}}


\sbox{\FIRM}
 {\parbox[t]{\headfield}{
 \ifthenelse{\equal{\fromlogo}{}}{}
{\centerline{\includegraphics[height=2.5cm]{\fromlogo}}}
    \baselineskip18pt \xiisf
    \makebox[\headfield][s]{\hfil\xivsfbx \MakeUppercase{\fromname}\hfil }\\
     \ifthenelse{\equal{\instname}{}}{}{\makebox[\headfield][s]{\xivsf\hfil \instname\hfil}}
      \ifthenelse{\equal{\specname}{}}{}{\makebox[\headfield][s]{\hfil \specname\hfil}}
    \ifthenelse{\equal{\dept}{}}{}{\makebox[\headfield][s]{\hfil \dept\hfil}}
    \hfil\usebox{\fromaddressbox}\hfil\\
    \ifthenelse{\equal{\countryname}{USA}\OR\equal{\countryname}{UK}}
    {\makebox[\headfield][s]{%
        \hfil \cityname\ \fromcode\ (\countryname)\hfil}}
    {\makebox[\headfield][s]{%
        \hfil \fromcode\ \cityname\ \ifthenelse{\equal{\@cedex}{}}{}{cedex \@cedex\ }(\countryname)\hfil}}
        }}

\sbox{\firm}
 {\xsf }

\newsavebox{\firmhead}  \newsavebox{\firmfoot}

\sbox{\citydate}
    {\parbox[b]{\rightfield}{\xsf \cityname, \@date}}
\sbox{\firmhead}
 {\parbox{\textwidth}{%
    \usebox{\FIRM}\hfill\raisebox{-0pt}{\usebox{\citydate}}}}

\sbox{\firmfoot}
 {\parbox{\textwidth}{\rule{\textwidth}{0.6pt}\\[5pt]
    \xsf\setlength{\baselineskip}{12pt}%
    \makebox[\textwidth][c]{%
    \telephonename: \fromtelcode\,\telephonenum\ -- %
    \ifthenelse{\equal\@faxnum{}}{}{Fax: \fromtelcode\,\@faxnum\ -- }
    \ifthenelse{\equal\webp@ge{}}{}{Web: \webp@ge\ -- }
    E-mail: \@internet\INTERNET}
    }}

\renewcommand{\ps@firstpage}
 {\setlength{\headheight}{41pt}\setlength{\headsep}{25pt}%
   \renewcommand{\@oddhead}{\usebox{\firmhead}}%
   \renewcommand{\@oddfoot}{\raisebox{-21pt}[0pt]
    {\usebox{\firmfoot}}}%
   \renewcommand{\@evenhead}{}\renewcommand{\@evenfoot}{}}

\renewcommand{\ps@headings}
 {\setlength{\headheight}{41pt}%
    \renewcommand{\@oddhead}
      {\parbox{\textwidth}{\usebox}{\firm}\\[2\parskip]
        \slshape \headtoname{}: \toname\hfill\@date\hfill
            \pagename{} \thepage\\
        \rule[3pt]{\textwidth}{1pt}}}
\renewcommand{\@oddfoot}{}
\renewcommand{\@evenhead}{\@oddhead}
\renewcommand{\@evenfoot}{\@oddfoot}

\providecommand{\@evenhead}{}   \providecommand{\@oddhead}{}
\providecommand{\@evenfoot}{}   \providecommand{\@oddfoot}{}}

\pagestyle{headings}

\renewcommand{\opening}[1]{%
    \thispagestyle{firstpage}%
 \begin{minipage}[t]{\textwidth}
 \mbox{}\\\mbox{}\\\mbox{}\\\mbox{}\\
 \parbox[b]{\leftfield}{\ }%
    \parbox[b]{\rightfield}{\sloppy\toname\\\toaddress}
    \end{minipage}
 \vspace{\parskip}
    \par
 \ifthenelse{\equal{\@subject}{}}
    {}{\vspace{2\parskip}\subjectname: \textbf{\@subject}\par}
 \vspace{2\parskip} #1 \par\nobreak}

\renewcommand{\closing}[1]{\par\nobreak\vspace{\parskip}%
  \stopbreaks
  \noindent
  \parbox[t]{\leftfield}{%
  \parbox[t]{\leftfield}{\ }%
    \parbox[b][3.5cm][c]{\rightfield}{%
  \ifx\@empty\fromaddress\else\relax\fi
       \ignorespaces #1\\[6\medskipamount]%
       \ifx\@empty\fromsig
           \fromname
       \else \fromsig \fi\strut}%
       }
   \par}
